@@ -15,10 +15,10 @@
 """Define API Datasets."""
 import six
 
+from google.api.core import page_iterator
 from google.cloud._helpers import _datetime_from_microseconds
 from google.cloud.exceptions import NotFound
 from google.cloud.bigquery.table import Table
-from google.cloud.iterator import HTTPIterator
 
 
 class AccessGrant(object):
@@ -76,11 +76,16 @@ class AccessGrant(object):
         self.entity_id = entity_id
 
     def __eq__(self, other):
+        if not isinstance(other, AccessGrant):
+            return NotImplemented
         return (
             self.role == other.role and
             self.entity_type == other.entity_type and
             self.entity_id == other.entity_id)
 
+    def __ne__(self, other):
+        return not self == other
+
     def __repr__(self):
         return '<AccessGrant: role=%s, %s=%s>' % (
             self.role, self.entity_type, self.entity_id)
@@ -531,7 +536,7 @@ class Dataset(object):
         """API call:  delete the dataset via a DELETE request.
 
         See
-        https://cloud.google.com/bigquery/docs/reference/rest/v2/tables/delete
+        https://cloud.google.com/bigquery/docs/reference/rest/v2/datasets/delete
 
         :type client: :class:`~google.cloud.bigquery.client.Client` or
                       ``NoneType``
@@ -556,14 +561,19 @@ class Dataset(object):
                            datasets. If not passed, the API will return the
                            first page of datasets.
 
-        :rtype: :class:`~google.cloud.iterator.Iterator`
+        :rtype: :class:`~google.api.core.page_iterator.Iterator`
         :returns: Iterator of :class:`~google.cloud.bigquery.table.Table`
                   contained within the current dataset.
         """
         path = '/projects/%s/datasets/%s/tables' % (self.project, self.name)
-        result = HTTPIterator(client=self._client, path=path,
-                              item_to_value=_item_to_table, items_key='tables',
-                              page_token=page_token, max_results=max_results)
+        result = page_iterator.HTTPIterator(
+            client=self._client,
+            api_request=self._client._connection.api_request,
+            path=path,
+            item_to_value=_item_to_table,
+            items_key='tables',
+            page_token=page_token,
+            max_results=max_results)
         result.dataset = self
         return result
 
@@ -585,7 +595,7 @@ class Dataset(object):
 def _item_to_table(iterator, resource):
     """Convert a JSON table to the native object.
 
-    :type iterator: :class:`~google.cloud.iterator.Iterator`
+    :type iterator: :class:`~google.api.core.page_iterator.Iterator`
     :param iterator: The iterator that is currently in use.
 
     :type resource: dict
